# Generated by Django 5.0.1 on 2024-02-18 20:28

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("artd_order", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="order",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="order",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="orderadress",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="orderadress",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="orderdeliverymethod",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="orderdeliverymethod",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="orderpaymenthistory",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="orderpaymenthistory",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="orderproduct",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="orderproduct",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="orderstatus",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="orderstatus",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="orderstatushistory",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="orderstatushistory",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
    ]
